@@ -8,4 +8,12 @@ USER_AGENT = {
     "Win10_Chrome77":
         ("Mozilla/5.0 (Windows NT 10.0; Win64; x64) "
          "AppleWebKit/537.36 (KHTML, like Gecko) Chrome/77.0.3865.90 Safari/537.36"),
+
+    # Windows系统(Win10):Chrome浏览器(83.0.4103.61)
+    "Win10_Chrome83":
+        ("Mozilla/5.0 (Windows NT 10.0; Win64; x64) "
+         "AppleWebKit/537.36 (KHTML, like Gecko) Chrome/83.0.4103.61 Safari/537.36"),
 }
+
+# 默认UserAgent
+DEFAULT_USER_AGENT = USER_AGENT["Win10_Chrome83"]
